@@ -71,7 +71,7 @@ use Sys::Virt::NWFilter;
 use Sys::Virt::DomainSnapshot;
 use Sys::Virt::Stream;
 
-our $VERSION = '0.9.7';
+our $VERSION = '0.9.8';
 require XSLoader;
 XSLoader::load('Sys::Virt', $VERSION);
 
@@ -1162,6 +1162,17 @@ or encryption with a TCP stream.
 Returns a true value if the current connection data stream is
 encrypted.
 
+=item $conn->is_alive()
+
+Returns a true value if the connection is alive, as determined
+by keep-alive packets or other recent RPC traffic.
+
+=item $conn->set_keep_alive($interval, $count)
+
+Change the operation of the keep alive protocol to send C<$count>
+packets spaced C<$interval> seconds apart before considering the
+connection dead.
+
 =item my $info = $con->get_node_info()
 
 Returns a hash reference summarising the capabilities of the host
@@ -1231,6 +1242,12 @@ The memory consumed for cache
 
 =back
 
+=item $conn->node_suspend_for_duration($target, $duration, $flags=0)
+
+Suspend the the host, using mode C<$target> which is one of the NODE
+SUSPEND constants listed later. The C<$duration> parameter controls
+how long the node is suspended for before waking up.
+
 =item $conn->domain_event_register($callback)
 
 Register a callback to received notificaitons of domain state change
@@ -1468,6 +1485,24 @@ The host offers a superset of the CPU descriptoon
 
 =back
 
+=head2 NODE SUSPEND CONSTANTS
+
+=over 4
+
+=item Sys::Virt::NODE_SUSPEND_TARGET_MEM
+
+Suspends to memory (equivalent of S3 on x86 architectures)
+
+=item Sys::Virt::NODE_SUSPEND_TARGET_DISK
+
+Suspends to disk (equivalent of S5 on x86 architectures)
+
+=item Sys::Virt::NODE_SUSPEND_TARGET_HYBRID
+
+Suspends to memory and disk (equivalent of S3+S5 on x86 architectures)
+
+=back
+
 =head1 BUGS
 
 Hopefully none, but the XS code needs to be audited to ensure it
